@@ -1,4 +1,5 @@
 use pyo3::{prelude::*, Python};
+use pyo3_stub_gen::derive::gen_stub_pyfunction;
 use statsig_rust::log_w;
 use std::sync::atomic::{AtomicBool, Ordering};
 
@@ -6,6 +7,7 @@ lazy_static::lazy_static! {
     static ref PYTHON_RUNNING: AtomicBool = AtomicBool::new(true);
 }
 
+#[gen_stub_pyfunction]
 #[pyfunction]
 pub fn notify_python_shutdown() {
     PYTHON_RUNNING.store(false, Ordering::SeqCst);
